==> mktcenter-service-1.5.3-vg-20221108.085411-15-sources.jar: com/bizvane/mktcenterservice/models/dto/ChannelRecordInfoDto.java <==
package com.bizvane.mktcenterservice.models.dto;

import com.bizvane.mktcenterservice.models.po.MktContentChannelSourceActionPo;
import com.bizvane.mktcenterservice.models.po.MktContentChannelSourcePo;
import com.github.pagehelper.PageInfo;

public class ChannelRecordInfoDto {

    /** 投放渠道数 */
    private Integer channelNum;

    /** 渠道预览占比 */
    private String channelPreviewRate;

    /** 内容预览数 */
    private Long contentPreviewNum;

    /** 预览用户数 */
    private Long membersPreviewNum;

    /** 注册会员数 */
    private Long membersRegisterNum;

    /** 绑定会员数 */
    private Long membersBindNum;

    /** 点亮俱乐部会员数 */
    private Long membersJoinClubNum;

    /** 来源明细 列表数据 */
    private PageInfo<MktContentChannelSourcePo> sourceList;

    /** 会员明细 列表数据 */
    private PageInfo<MktContentChannelSourceActionPo> sourceActionList;

    //只做数据处理用字段
    /** 渠道预览数 */
    private String pv;
    /** 总预览数 */
    private String totalPv;

    public Integer getChannelNum() {
        return channelNum;
    }

    public void setChannelNum(Integer channelNum) {
        this.channelNum = channelNum;
    }

    public String getChannelPreviewRate() {
        return channelPreviewRate;
    }

    public void setChannelPreviewRate(String channelPreviewRate) {
        this.channelPreviewRate = channelPreviewRate;
    }

    public Long getContentPreviewNum() {
        return contentPreviewNum;
    }

    public void setContentPreviewNum(Long contentPreviewNum) {
        this.contentPreviewNum = contentPreviewNum;
    }

    public Long getMembersPreviewNum() {
        return membersPreviewNum;
    }

    public void setMembersPreviewNum(Long membersPreviewNum) {
        this.membersPreviewNum = membersPreviewNum;
    }

    public Long getMembersRegisterNum() {
        return membersRegisterNum;
    }

    public void setMembersRegisterNum(Long membersRegisterNum) {
        this.membersRegisterNum = membersRegisterNum;
    }

    public Long getMembersBindNum() {
        return membersBindNum;
    }

    public void setMembersBindNum(Long membersBindNum) {
        this.membersBindNum = membersBindNum;
    }

    public Long getMembersJoinClubNum() {
        return membersJoinClubNum;
    }

    public void setMembersJoinClubNum(Long membersJoinClubNum) {
        this.membersJoinClubNum = membersJoinClubNum;
    }

    public PageInfo<MktContentChannelSourcePo> getSourceList() {
        return sourceList;
    }

    public void setSourceList(PageInfo<MktContentChannelSourcePo> sourceList) {
        this.sourceList = sourceList;
    }

    public PageInfo<MktContentChannelSourceActionPo> getSourceActionList() {
        return sourceActionList;
    }

    public void setSourceActionList(PageInfo<MktContentChannelSourceActionPo> sourceActionList) {
        this.sourceActionList = sourceActionList;
    }

    public String getPv() {
        return pv;
    }

    public void setPv(String pv) {
        this.pv = pv;
    }

    public String getTotalPv() {
        return totalPv;
    }

    public void setTotalPv(String totalPv) {
        this.totalPv = totalPv;
    }
}

==> mktcenter-service-1.5.7-vg-20231121.030929-1-sources.jar: com/bizvane/mktcenterservice/models/dto/ChannelRecordInfoDto.java <==
package com.bizvane.mktcenterservice.models.dto;

import com.bizvane.mktcenterservice.models.po.MktContentChannelSourceActionPo;
import com.bizvane.mktcenterservice.models.po.MktContentChannelSourcePo;
import com.github.pagehelper.PageInfo;

public class ChannelRecordInfoDto {

    /** 投放渠道数 */
    private Integer channelNum;

    /** 渠道预览占比 */
    private String channelPreviewRate;

    /** 内容预览数 */
    private Long contentPreviewNum;

    /** 预览用户数 */
    private Long membersPreviewNum;

    /** 注册会员数 */
    private Long membersRegisterNum;

    /** 绑定会员数 */
    private Long membersBindNum;

    /** 点亮俱乐部会员数 */
    private Long membersJoinClubNum;

    /** 来源明细 列表数据 */
    private PageInfo<MktContentChannelSourcePo> sourceList;

    /** 会员明细 列表数据 */
    private PageInfo<MktContentChannelSourceActionPo> sourceActionList;

    //只做数据处理用字段
    /** 渠道预览数 */
    private String pv;
    /** 总预览数 */
    private String totalPv;

    /**
     * 参与会员数
     */
    private Long partakenNum;

    /**
     * 领券会员数
     */
    private Long getCouponNum;

    /**
     * 兑换会员数
     */
    private Long exchangeNum;

    public Long getPartakenNum() {
        return partakenNum;
    }

    public Long getGetCouponNum() {
        return getCouponNum;
    }

    public Long getExchangeNum() {
        return exchangeNum;
    }

    public void setPartakenNum(Long partakenNum) {
        this.partakenNum = partakenNum;
    }

    public void setGetCouponNum(Long getCouponNum) {
        this.getCouponNum = getCouponNum;
    }

    public void setExchangeNum(Long exchangeNum) {
        this.exchangeNum = exchangeNum;
    }

    public Integer getChannelNum() {
        return channelNum;
    }

    public void setChannelNum(Integer channelNum) {
        this.channelNum = channelNum;
    }

    public String getChannelPreviewRate() {
        return channelPreviewRate;
    }

    public void setChannelPreviewRate(String channelPreviewRate) {
        this.channelPreviewRate = channelPreviewRate;
    }

    public Long getContentPreviewNum() {
        return contentPreviewNum;
    }

    public void setContentPreviewNum(Long contentPreviewNum) {
        this.contentPreviewNum = contentPreviewNum;
    }

    public Long getMembersPreviewNum() {
        return membersPreviewNum;
    }

    public void setMembersPreviewNum(Long membersPreviewNum) {
        this.membersPreviewNum = membersPreviewNum;
    }

    public Long getMembersRegisterNum() {
        return membersRegisterNum;
    }

    public void setMembersRegisterNum(Long membersRegisterNum) {
        this.membersRegisterNum = membersRegisterNum;
    }

    public Long getMembersBindNum() {
        return membersBindNum;
    }

    public void setMembersBindNum(Long membersBindNum) {
        this.membersBindNum = membersBindNum;
    }

    public Long getMembersJoinClubNum() {
        return membersJoinClubNum;
    }

    public void setMembersJoinClubNum(Long membersJoinClubNum) {
        this.membersJoinClubNum = membersJoinClubNum;
    }

    public PageInfo<MktContentChannelSourcePo> getSourceList() {
        return sourceList;
    }

    public void setSourceList(PageInfo<MktContentChannelSourcePo> sourceList) {
        this.sourceList = sourceList;
    }

    public PageInfo<MktContentChannelSourceActionPo> getSourceActionList() {
        return sourceActionList;
    }

    public void setSourceActionList(PageInfo<MktContentChannelSourceActionPo> sourceActionList) {
        this.sourceActionList = sourceActionList;
    }

    public String getPv() {
        return pv;
    }

    public void setPv(String pv) {
        this.pv = pv;
    }

    public String getTotalPv() {
        return totalPv;
    }

    public void setTotalPv(String totalPv) {
        this.totalPv = totalPv;
    }
}
